Received: from localhost (maia-1.hub.org [200.46.204.191]) by postgresql.org (Postfix) with ESMTP id F28D39FA22A for ; Tue, 6 Feb 2007 10:55:46 -0400 (AST) Received: from postgresql.org ([200.46.204.71]) by localhost (mx1.hub.org [200.46.204.191]) (amavisd-new, port 10024) with ESMTP id 56982-03 for ; Tue, 6 Feb 2007 10:55:30 -0400 (AST) X-Greylist: from auto-whitelisted by SQLgrey-1.7.4 Received: from floppy.pyrenet.fr (news.pyrenet.fr [194.116.145.2]) by postgresql.org (Postfix) with ESMTP id 06F4F9FA59C for ; Tue, 6 Feb 2007 10:55:29 -0400 (AST) Received: by floppy.pyrenet.fr (Postfix, from userid 106) id A30A830952; Tue, 6 Feb 2007 15:55:28 +0100 (MET) From: Mark Stosberg X-Newsgroups: pgsql.performance Subject: Re: explain analyze output: vacuuming made a big difference. Date: Tue, 06 Feb 2007 09:54:59 -0500 Organization: Hub.Org Networking Services Lines: 22 Message-ID: References: <20070204051644.GA3754@wolff.to> <20070206054011.GA9604@wolff.to> Mime-Version: 1.0 Content-Type: text/plain; charset=ISO-8859-1 Content-Transfer-Encoding: 7bit X-Complaints-To: usenet@news.hub.org User-Agent: Thunderbird 1.5.0.8 (X11/20061109) In-Reply-To: To: pgsql-performance@postgresql.org X-Virus-Scanned: Maia Mailguard 1.0.1 X-Archive-Number: 200702/64 X-Sequence-Number: 23118 Mark Stosberg wrote: > > I'm reading the explain analyze output correctly myself, nearly all of > the time spent is related to the 'pets' table, but I can't see what to > about it. Something about typing that message jarred by brain to think to try: VACUUM FULL pets; VACUUM ANALYZE pets; Now the new cube-based calculation benchmarks reliably faster. The old lat/lon systems now benchmarks at 250ms, while the the new cube-based code bechmarks at 100ms, over a 50% savings! That's good enough for me. However, I'm still interested advice on the other points I snuck into my last message about joining with ints vs varchars and best use of partial indexes. Mark